{% extends "pinax/announcements/base.html" %} {% load i18n %} {% block head_title %}{% trans "Announcements Admin" %}{% endblock %} {% block body %}

## {% trans "Announcements" %} {% trans "Add New Announcement" %}

{% for announcement in announcement_list %}
{{ announcement.title }}
{{ announcement.content }}
{% if announcement.publish_start or announcement.publish_end %} Published from {{ announcement.publish_start|date:"F j, Y" }} to {{ announcement.publish_end|date:"F j, Y" }} {% endif %}
{% trans "Edit" %}
{% endfor %} {% endblock %}